![GitHub Workflow Status](https://img.shields.io/github/workflow/status/jodhus/pyebur128/Run%20tests)
[![codecov](https://codecov.io/gh/jodhus/pyebur128/branch/master/graph/badge.svg?token=TLA2NXMEF4)](https://codecov.io/gh/jodhus/pyebur128)
![GitHub](https://img.shields.io/github/license/jodhus/pyebur128)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pyebur128)
![PyPI](https://img.shields.io/pypi/v/pyebur128)


# pyebur128
A Cython implementation of the [libebur128](https://github.com/jiixyj/libebur128) library for audio loudness in media files.

## Requirements

* Operating Systems: Linux, macOS, or Windows
* Python: 3.6+
* Dependencies: None!

## Installation

### PyPI

```
pip install pyebur128
```

### From Source

```
git clone --recurse-submodules https://github.com/jodhus/pyebur128
cd pyebur128
pip install .
```

## TODO
* Working on getting official documentation written/uploaded. In the meantime, all definitions are documented in within their docstrings.